@@ -4,7 +4,6 @@
 
 #ifdef ITK_STATIC
 #  define ITKFEM_EXPORT
-#  define ITKFEM_TEMPLATE_EXPORT
 #  define ITKFEM_HIDDEN
 #else
 #  ifndef ITKFEM_EXPORT
@@ -17,16 +16,6 @@
 #    endif
 #  endif
 
-#  ifndef ITKFEM_TEMPLATE_EXPORT
-#    ifdef ITKFEM_EXPORTS
-        /* We are building this library */
-#      define ITKFEM_TEMPLATE_EXPORT 
-#    else
-        /* We are using this library */
-#      define ITKFEM_TEMPLATE_EXPORT 
-#    endif
-#  endif
-
 #  ifndef ITKFEM_HIDDEN
 #    define ITKFEM_HIDDEN 
 #  endif
