@@ -4,7 +4,6 @@
 
 #ifdef ITK_STATIC
 #  define ITKVTK_EXPORT
-#  define ITKVTK_TEMPLATE_EXPORT
 #  define ITKVTK_HIDDEN
 #else
 #  ifndef ITKVTK_EXPORT
@@ -17,16 +16,6 @@
 #    endif
 #  endif
 
-#  ifndef ITKVTK_TEMPLATE_EXPORT
-#    ifdef ITKVTK_EXPORTS
-        /* We are building this library */
-#      define ITKVTK_TEMPLATE_EXPORT 
-#    else
-        /* We are using this library */
-#      define ITKVTK_TEMPLATE_EXPORT 
-#    endif
-#  endif
-
 #  ifndef ITKVTK_HIDDEN
 #    define ITKVTK_HIDDEN 
 #  endif
