@@ -40,9 +40,9 @@
 
 /* Usefull in particular for loadshared where the full path
  * to the lib is needed */
-#define GDCM_SOURCE_DIR "C:/bld/itk_1494852954295/work/ITK-4.11.1/Modules/ThirdParty/GDCM/src/gdcm"
-#define GDCM_EXECUTABLE_OUTPUT_PATH "C:/bld/itk_1494852954295/work/ITK-4.11.1/bld/bin"
-#define GDCM_LIBRARY_OUTPUT_PATH    "C:/bld/itk_1494852954295/work/ITK-4.11.1/bld/lib"
+#define GDCM_SOURCE_DIR "C:/bld/itk_1499277177883/work/ITK-4.12.0/Modules/ThirdParty/GDCM/src/gdcm"
+#define GDCM_EXECUTABLE_OUTPUT_PATH "C:/bld/itk_1499277177883/work/ITK-4.12.0/bld/bin"
+#define GDCM_LIBRARY_OUTPUT_PATH    "C:/bld/itk_1499277177883/work/ITK-4.12.0/bld/lib"
 
 /* #undef GDCM_BUILD_TESTING */
 
@@ -84,7 +84,7 @@
 /* #undef GDCM_AUTOLOAD_GDCMJNI */
 
 /* I guess something important */
-#define GDCM_HAVE_STDINT_H
+/* #undef GDCM_HAVE_STDINT_H */
 /* #undef GDCM_HAVE_INTTYPES_H */
 
 /* This variable allows you to have helpful debug statement */
@@ -93,9 +93,9 @@
 /* only cerr, for instance 'invalid file' will be allowed */
 /* #undef GDCM_DEBUG */
 
-#define GDCM_CMAKE_INSTALL_PREFIX "C:/bld/itk_1494852954295/_b_env/Library"
-#define GDCM_INSTALL_INCLUDE_DIR "include/ITK-4.11"
-#define GDCM_INSTALL_DATA_DIR "share/ITK-4.11/gdcm"
+#define GDCM_CMAKE_INSTALL_PREFIX "C:/bld/itk_1499277177883/_b_env/Library"
+#define GDCM_INSTALL_INCLUDE_DIR "include/ITK-4.12"
+#define GDCM_INSTALL_DATA_DIR "share/ITK-4.12/gdcm"
 
 /* Whether we are building shared libraries.  */
 /* #undef GDCM_BUILD_SHARED_LIBS */
@@ -115,11 +115,11 @@
 
 /* #undef GDCM_HAVE_STRCASECMP */
 /* #undef GDCM_HAVE_STRNCASECMP */
-#define GDCM_HAVE_SNPRINTF
+/* #undef GDCM_HAVE_SNPRINTF */
 /* #undef GDCM_HAVE_STRPTIME */
 #define GDCM_HAVE__STRICMP
 #define GDCM_HAVE__STRNICMP
-/* #undef GDCM_HAVE__SNPRINTF */
+#define GDCM_HAVE__SNPRINTF
 /* #undef GDCM_HAVE_LROUND */
 /* #undef GDCM_HAVE_GETTIMEOFDAY */
 /* #undef GDCM_HAVE_JSON_OBJECT_OBJECT_GET_EX */
