@@ -94,13 +94,14 @@
 #define ITK_COMPILER_SUPPORTS_SSE2_64
 /* #undef ITK_USE_GPU */
 /* #undef ITK_TEMPLATE_VISIBILITY_DEFAULT */
+/* #undef USE_COMPILER_HIDDEN_VISIBILITY */
 
 // defined if the system has <tr1/type_traits> header
 /* #undef ITK_HAS_STLTR1_TR1_TYPE_TRAITS */
 // defined if the system has <type_traits> header
 #define ITK_HAS_STLTR1_TYPE_TRAITS
 // defined if std type traits are with C++11 ( no tr1 namespace )
-/* #undef ITK_HAS_CPP11_TYPETRAITS */
+#define ITK_HAS_CPP11_TYPETRAITS
 // defined if the compiler support GNU's __attribute__(( algined(x) )) extension
 /* #undef ITK_HAS_GNU_ATTRIBUTE_ALIGNED */
 // defined if the STL implementation includes std::copy_n
@@ -139,13 +140,13 @@
  * conditionally defined them here with an ITK_ prefix to prevent
  * collisions and re defined warnings.
  */
-#if ITK_CMAKEDEFINE_VAR_
+#if ITK_CMAKEDEFINE_VAR_1
 # define ITK_HAVE_FENV_H
 #endif /* HAVE_FENV_H */
 #if ITK_CMAKEDEFINE_VAR_1
 # define ITK_HAVE_SYS_TYPES_H
 #endif  /* HAVE_SYS_TYPES_H */
-#if ITK_CMAKEDEFINE_VAR_
+#if ITK_CMAKEDEFINE_VAR_1
 # define ITK_HAVE_STDINT_H
 #endif  /* HAVE_STDINT_H */
 #if ITK_CMAKEDEFINE_VAR_1
@@ -164,8 +165,8 @@
 
 
 #define ITK_VERSION_MAJOR 4
-#define ITK_VERSION_MINOR 11
-#define ITK_VERSION_PATCH 1
-#define ITK_VERSION_STRING "4.11"
+#define ITK_VERSION_MINOR 12
+#define ITK_VERSION_PATCH 0
+#define ITK_VERSION_STRING "4.12"
 
 #endif //itkConfigure_h
